@@ -3,11 +3,12 @@ import os
 from io import StringIO
 
 import paramiko
-from dagster import Field, StringSource, check, resource
-from dagster.utils import merge_dicts, mkdir_p
 from paramiko.config import SSH_PORT
 from sshtunnel import SSHTunnelForwarder
 
+from dagster import Field, StringSource, check, resource
+from dagster.utils import merge_dicts, mkdir_p
+
 
 def key_from_str(key_str):
     """Creates a paramiko SSH key from a string."""
@@ -252,5 +253,5 @@ class SSHResource:
 )
 def ssh_resource(init_context):
     args = init_context.resource_config
-    args = merge_dicts(init_context.resource_config, {"logger": init_context.log_manager})
+    args = merge_dicts(init_context.resource_config, {"logger": init_context.log})
     return SSHResource(**args)
